/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE TABLE OD_SMENE (
    ID             VARCHAR(10) NOT NULL,
    NAZIV          VARCHAR(20),
    SIFRA_RADNIKA  INTEGER,
    VREME          TIMESTAMP
);
ALTER TABLE OD_SMENE ADD CONSTRAINT PK_OD_SMENE PRIMARY KEY (ID);

CREATE TABLE OD_M_UZORKA (
    ID             VARCHAR(10) NOT NULL,
    NAZIV          VARCHAR(30),
    IDMASINE       VARCHAR(10),
    IDODELJENJA    INTEGER,
    SIFRA_RADNIKA  INTEGER,
    VREME          TIMESTAMP
);

ALTER TABLE OD_M_UZORKA ADD CONSTRAINT PK_OD_M_UZORKA PRIMARY KEY (ID);
CREATE INDEX OD_M_UZORKA_IDX1 ON OD_M_UZORKA (NAZIV);
CREATE INDEX OD_M_UZORKA_IDX2 ON OD_M_UZORKA (IDMASINE);


CREATE TABLE OD_LIST (
    ID             VARCHAR(10) NOT NULL,
    NAZIV          VARCHAR(30),
    OZNAKA         VARCHAR(10),
    OPIS           VARCHAR(150),
    SIFRA_RADNIKA  INTEGER,
    VREME          TIMESTAMP
);

ALTER TABLE OD_LIST ADD CONSTRAINT PK_OD_LIST PRIMARY KEY (ID);


CREATE TABLE OD_GRADE (
    ID             VARCHAR(10) NOT NULL,
    NAZIV          VARCHAR(30),
    OPIS           VARCHAR(150),
    SIFRA_RADNIKA  INTEGER,
    VREME          TIMESTAMP
);

ALTER TABLE OD_GRADE ADD CONSTRAINT PK_OD_GRADE PRIMARY KEY (ID);


CREATE TABLE OD_TRANSAKCIJE (
    ID    INTEGER NOT NULL,
    OPIS  VARCHAR(50),
    TIP   VARCHAR(10)
);


CREATE TABLE OD_PARAMETRI_MER (
    ID             VARCHAR(10) NOT NULL,
    NAZIV          VARCHAR(50),
    TIP            VARCHAR(10),
    SIFRA_RADNIKA  INTEGER,
    UNOS           TIMESTAMP,
    REDOSLED       SMALLINT,
    IDGRUPE        VARCHAR(10),
    MIN_VALUE      DOUBLE PRECISION,
    MAX_VALUE      DOUBLE PRECISION,
    STAND_VALUE    DOUBLE PRECISION
);

ALTER TABLE OD_PARAMETRI_MER ADD CONSTRAINT PK_OD_PARAMETRI_MER PRIMARY KEY (ID);
CREATE INDEX OD_PARAMETRI_MER_IDX1 ON OD_PARAMETRI_MER (TIP);

CREATE TABLE OD_GRUPE_PRIM (
    ID             VARCHAR(10) NOT NULL,
    NAZIV          VARCHAR(30),
    SIFRA_RADNIKA  INTEGER,
    VREMA          TIMESTAMP
);


ALTER TABLE OD_GRUPE_PRIM ADD CONSTRAINT PK_OD_GRUPE_PRIM PRIMARY KEY (ID);

alter table OD_TRANSAKCIJE add constraint PK_OD_TRANSAKCIJE primary key (ID);

CREATE TABLE OD_PROCESSING (
    ID                 INTEGER NOT NULL,
    DATUM              DATE,
    IDGRADE            VARCHAR(10),
    IDSMENE            VARCHAR(10),
    IDLIST             VARCHAR(10),
    RUNDAY             INTEGER,
    IDBLEND            INTEGER,
    BATCH_NO           VARCHAR(10),
    CASE_NO            INTEGER,
    IDLABORANTA        INTEGER,
    SIFRA_RADNIKA      INTEGER,
    VREME              TIME,
    IZMENA             TIMESTAMP,
    VRSTA_TRANSAKCIJE  INTEGER,
    ID_UZORKA          VARCHAR(10),
    VLAGA              DOUBLE PRECISION,
    TEMPERATURA        DOUBLE PRECISION,
    KOLICINA           DOUBLE PRECISION,
    STATUS             CHAR(1),
    UNOS               TIMESTAMP,
    VEZA               INTEGER,
    SUGAR              DOUBLE PRECISION,
    NICOTIN            DOUBLE PRECISION,
    GRADE              VARCHAR(30),
    SMENA              VARCHAR(30),
    LIST               VARCHAR(30),
    LABORANT           VARCHAR(30),
    MESTO_UZORKA       VARCHAR(50),
    IDTIP              INTEGER
);

ALTER TABLE OD_PROCESSING ADD CONSTRAINT PK_OD_PROCESSING PRIMARY KEY (ID);

ALTER TABLE OD_PROCESSING ADD CONSTRAINT FK_OD_PROCESSING_1 FOREIGN KEY (SIFRA_RADNIKA) REFERENCES TBLRADNICI (SIFRA_RADNIKA);
ALTER TABLE OD_PROCESSING ADD CONSTRAINT FK_OD_PROCESSING_2 FOREIGN KEY (IDGRADE) REFERENCES OD_GRADE (ID);
ALTER TABLE OD_PROCESSING ADD CONSTRAINT FK_OD_PROCESSING_3 FOREIGN KEY (VRSTA_TRANSAKCIJE) REFERENCES OD_TRANSAKCIJE (ID);
ALTER TABLE OD_PROCESSING ADD CONSTRAINT FK_OD_PROCESSING_4 FOREIGN KEY (VEZA) REFERENCES OD_PROCESSING (ID);
ALTER TABLE OD_PROCESSING ADD CONSTRAINT FK_OD_PROCESSING_5 FOREIGN KEY (IDTIP) REFERENCES TBLDUVAN (ID);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/
SET TERM ^ ;

/* Trigger: OD_PROCESSING_BI0 */
CREATE OR ALTER TRIGGER OD_PROCESSING_BI0 FOR OD_PROCESSING
ACTIVE BEFORE INSERT POSITION 0
AS
begin
  new.unos='NOW';
end
^


SET TERM ; ^

CREATE TABLE OD_LAB_MERENJA (
    ID              INTEGER NOT NULL,
    IDPROCESA       INTEGER,
    PARAMETAR1      VARCHAR(10),
    PARAMETAR2      VARCHAR(10),
    PARAMETAR3      VARCHAR(10),
    KOLICINA        DOUBLE PRECISION,
    IZMENA          TIMESTAMP,
    SIFRA_RADNIKA2  INTEGER,
    VREDNOST        DOUBLE PRECISION,
    PROCENAT        DOUBLE PRECISION
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE OD_LAB_MERENJA ADD CONSTRAINT PK_OD_LAB_MERENJA PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE OD_LAB_MERENJA ADD CONSTRAINT FK_OD_LAB_MERENJA_1 FOREIGN KEY (IDPROCESA) REFERENCES OD_PROCESSING (ID);
ALTER TABLE OD_LAB_MERENJA ADD CONSTRAINT FK_OD_LAB_MERENJA_2 FOREIGN KEY (PARAMETAR1) REFERENCES OD_PARAMETRI_MER (ID);
ALTER TABLE OD_LAB_MERENJA ADD CONSTRAINT FK_OD_LAB_MERENJA_3 FOREIGN KEY (PARAMETAR2) REFERENCES OD_PARAMETRI_MER (ID);
ALTER TABLE OD_LAB_MERENJA ADD CONSTRAINT FK_OD_LAB_MERENJA_4 FOREIGN KEY (PARAMETAR3) REFERENCES OD_PARAMETRI_MER (ID);




CREATE TABLE OD_SMENE (
    ID VARCHAR(10) NOT NULL,
    NAZIV VARCHAR(20));

alter table OD_SMENE add constraint PK_OD_SMENE primary key (ID);

CREATE TABLE OD_M_UZORKA (
    ID VARCHAR(10) NOT NULL,
    NAZIV VARCHAR(30),
    IDMASINE VARCHAR(10),
    IDODELJENJA INTEGER);

alter table OD_M_UZORKA add constraint PK_OD_M_UZORKA primary key (ID);


CREATE TABLE OD_BLAND (
    ID VARCHAR(10) NOT NULL,
    NAZIV VARCHAR(30));

alter table OD_BLAND add constraint PK_OD_BLAND primary key (ID);

CREATE TABLE OD_GRUPE_PRIM (
    ID VARCHAR(10) NOT NULL,
    NAZIV VARCHAR(30));

alter table OD_GRUPE_PRIM add constraint PK_OD_GRUPE_PRIM primary key (ID);


CREATE TABLE OD_PRIMESE (
    ID VARCHAR(10) NOT NULL,
    NAZIV VARCHAR(30),
    IDGRUPE VARCHAR(10));

alter table OD_PRIMESE add constraint PK_OD_PRIMESE primary key (ID);

alter table OD_PRIMESE add constraint FK_OD_PRIMESE_1 foreign key (IDGRUPE) references OD_GRUPE_PRIM(ID);


CREATE TABLE OD_LIST (
    ID VARCHAR(10) NOT NULL,
    NAZIV VARCHAR(30),
    OZNAKA VARCHAR(10),
    OPIS VARCHAR(150));

alter table OD_LIST add constraint PK_OD_LIST primary key (ID);


CREATE TABLE OD_SITO (
    ID VARCHAR(10) NOT NULL,
    NAZIV VARCHAR(30),
    OPIS VARCHAR(150),
    IDMASINE INTEGER);

alter table OD_SITO add constraint PK_OD_SITO primary key (ID);


alter table OD_SITO add constraint FK_OD_SITO_1 foreign key (IDMASINE) references PRMASINA(ID);


CREATE TABLE OD_GRADE (
    ID VARCHAR(10) NOT NULL,
    NAZIV VARCHAR(30),
    OPIS VARCHAR(150));

alter table OD_GRADE add constraint PK_OD_GRADE primary key (ID);


CREATE TABLE OD_STANDARDNE_VRED (
    ID VARCHAR(10) NOT NULL,
    OPIS VARCHAR(50),
    MIN_VALUE DOUBLE PRECISION,
    MAX_VALUE DOUBLE PRECISION,
    STAND_VALUE DOUBLE PRECISION,
    GRUPA VARCHAR(10),
    PARAMETAR VARCHAR(30));

alter table OD_STANDARDNE_VRED add constraint PK_OD_STANDARDNE_VRED primary key (ID);


CREATE TABLE OD_BLEND (
    ID INTEGER NOT NULL,
    OPIS VARCHAR(20) NOT NULL,
    IDNO VARCHAR(20) NOT NULL,
    BATCH_NO VARCHAR(20) NOT NULL,
    ORDER_NO VARCHAR(20) NOT NULL,
    BERBA INTEGER,
    VAZI_OD DATE,
    BROJ_BLENDA INTEGER,
    DATUM DATE,
    SMENA VARCHAR(10),
    AKTIVAN SMALLINT,
    NAPOMENA VARCHAR(250));
	
alter table OD_BLEND
add constraint PK_OD_BLEND
primary key (ID);

CREATE SEQUENCE GEN_OD_BLEND_ID;

SET TERM ^ ;

create procedure sp_gen_od_blend_id
returns (id integer)
as
begin
  id = gen_id(gen_od_blend_id, 1);
  suspend;
end
^

SET TERM ; ^

CREATE TABLE OD_BLEND_STAVKE (
    ID INTEGER NOT NULL,
    IDBLENDA INTEGER,
    GRADE VARCHAR(20),
    BROJ_BALA DOUBLE PRECISION);
	
alter table OD_BLEND_STAVKE
add constraint PK_OD_BLEND_STAVKE
primary key (ID);

ALTER TABLE OD_BLEND ADD SIFRA_RADNIKA INTEGER;
ALTER TABLE OD_GRADE ADD SIFRA_RADNIKA INTEGER;
ALTER TABLE OD_BLEND_STAVKE ADD RB INTEGER;
ALTER TABLE OD_BLEND_STAVKE ADD PROCENAT DOUBLE PRECISION;
ALTER TABLE OD_BLEND_STAVKE ADD VREME TIMESTAMP;

alter table OD_BLEND_STAVKE
add constraint FK_OD_BLEND_STAVKE_1
foreign key (IDBLENDA)
references OD_BLEND(ID);


ALTER TABLE OD_BLAND ADD SIFRA_RADNIKA INTEGER;
ALTER TABLE OD_BLAND ADD VREME TIMESTAMP;
ALTER TABLE OD_GRADE ADD VREME TIMESTAMP;
ALTER TABLE OD_GRUPE_PRIM ADD SIFRA_RADNIKA INTEGER;
ALTER TABLE OD_GRUPE_PRIM ADD VREMA TIMESTAMP;

ALTER TABLE OD_LIST ADD SIFRA_RADNIKA INTEGER;
ALTER TABLE OD_LIST ADD VREME TIMESTAMP;
ALTER TABLE OD_M_UZORKA ADD SIFRA_RADNIKA INTEGER;
ALTER TABLE OD_M_UZORKA ADD VREME TIMESTAMP;
ALTER TABLE OD_PRIMESE ADD SIFRA_RADNIKA INTEGER;
ALTER TABLE OD_PRIMESE ADD VREME TIMESTAMP;
ALTER TABLE OD_SITO ADD SIFRA_RADNIKA INTEGER;
ALTER TABLE OD_SITO ADD VREME TIMESTAMP;
ALTER TABLE OD_SMENE ADD SIFRA_RADNIKA INTEGER;
ALTER TABLE OD_SMENE ADD VREME TIMESTAMP;


ALTER TABLE OD_PARAMETRI_MER ADD MIN_VALUE DOUBLE PRECISION;
ALTER TABLE OD_PARAMETRI_MER ADD MAX_VALUE DOUBLE PRECISION;
ALTER TABLE OD_PARAMETRI_MER ADD STAND_VALUE DOUBLE PRECISION;




SET TERM ^ ;

CREATE OR ALTER PROCEDURE OD_LAB_IZVESTAJ (
    od_datuma date,
    do_datuma date,
    id_transakcije integer)
returns (
    id integer,
    datum date,
    idgrade varchar(10),
    idsmene varchar(10),
    idlist varchar(10),
    runday integer,
    idblend integer,
    batch_no varchar(10),
    case_no integer,
    idlaboranta integer,
    sifra_radnika integer,
    vreme time,
    izmena timestamp,
    vrsta_transakcije integer,
    id_uzorka varchar(10),
    vlaga double precision,
    temperatura double precision,
    kolicina double precision,
    status char(1),
    unos timestamp,
    veza integer,
    sugar double precision,
    nicotin double precision,
    grade varchar(30),
    smena varchar(30),
    list varchar(30),
    laborant varchar(30),
    mesto_uzorka varchar(50),
    idtip integer,
    transakcija varchar(50),
    id_lab integer,
    idprocesa integer,
    parametar1 varchar(10),
    parametar2 varchar(10),
    parametar3 varchar(10),
    kolicina_obj double precision,
    vrednost_obj double precision,
    procenat_obj double precision,
    kolicina_7sl double precision,
    vrednost_7sl double precision,
    procenat_7sl double precision,
    kolicina_12sl double precision,
    vrednost_12sl double precision,
    procenat_12sl double precision,
    kolicina_12mesh double precision,
    vrednost_12mesh double precision,
    procenat_12mesh double precision,
    kolicina_pan double precision,
    vrednost_pan double precision,
    procenat_pan double precision)
as
BEGIN
  FOR
    select p.*,
           t.opis as transakcija
    from OD_PROCESSING p  INNER JOIN od_transakcije t ON t.id=p.vrsta_transakcije  
                                                                  and p.datum between :od_datuma and :do_datuma
                                                                  and p.vrsta_transakcije=:id_transakcije    
                                                                  and p.status<>'D'
    order by p.datum, p.vreme
    INTO :ID,
         :DATUM,
         :IDGRADE,
         :IDSMENE,
         :IDLIST,
         :RUNDAY,
         :IDBLEND,
         :BATCH_NO,
         :CASE_NO,
         :IDLABORANTA,
         :SIFRA_RADNIKA,
         :VREME,
         :IZMENA,
         :VRSTA_TRANSAKCIJE,
         :ID_UZORKA,
         :VLAGA,
         :TEMPERATURA,
         :KOLICINA,
         :STATUS,
         :UNOS,
         :VEZA,
         :SUGAR,
         :NICOTIN,
         :GRADE,
         :SMENA,
         :LIST,
         :LABORANT,
         :MESTO_UZORKA,
         :IDTIP,
         :TRANSAKCIJA
  DO
  BEGIN

    select kolicina, procenat
    from od_lab_merenja m
    where idprocesa=:id
    and parametar1='OBJS3/32'
    into :kolicina_obj, :procenat_obj;

    select kolicina, procenat
    from od_lab_merenja m
    where idprocesa=:id
    and parametar1='#7SLOTTED'
    into :kolicina_7sl, :procenat_7sl;

    select kolicina, procenat
    from od_lab_merenja m
    where idprocesa=:id
    and parametar1='#12SLOTTED'
    into :kolicina_12sl, :procenat_12sl;

    select kolicina, procenat
    from od_lab_merenja m
    where idprocesa=:id
    and parametar1='#12MESH'
    into :kolicina_12mesh, :procenat_12mesh;

    select kolicina, procenat
    from od_lab_merenja m
    where idprocesa=:id
    and parametar1='FIBONPAN'
    into :kolicina_pan, :procenat_pan;

        SUSPEND;

  END
END^

SET TERM ; ^



SET TERM ^ ;

CREATE OR ALTER PROCEDURE OD_LAB_IZV_DEGRAD (
    od_datuma date,
    do_datuma date,
    id_transakcije integer)
returns (
    id integer,
    datum date,
    idgrade varchar(10),
    idsmene varchar(10),
    idlist varchar(10),
    runday integer,
    idblend integer,
    batch_no varchar(10),
    case_no integer,
    idlaboranta integer,
    sifra_radnika integer,
    vreme time,
    izmena timestamp,
    vrsta_transakcije integer,
    id_uzorka varchar(10),
    vlaga double precision,
    temperatura double precision,
    kolicina double precision,
    status char(1),
    unos timestamp,
    veza integer,
    sugar double precision,
    nicotin double precision,
    grade varchar(30),
    smena varchar(30),
    list varchar(30),
    laborant varchar(30),
    mesto_uzorka varchar(50),
    idtip integer,
    transakcija varchar(50),
    id_lab integer,
    idprocesa integer,
    parametar1 varchar(10),
    parametar2 varchar(10),
    parametar3 varchar(10),
    kolicina_ov1 double precision,
    kolicina_ov12 double precision,
    kolicina_ov14 double precision,
    kolicina_ov18 double precision,
    kolicina_pan double precision)
as
BEGIN
  FOR
    select p.*,
           t.opis as transakcija
    from OD_PROCESSING p  INNER JOIN od_transakcije t ON t.id=p.vrsta_transakcije  
                                                                  and p.datum between :od_datuma and :do_datuma
                                                                  and p.vrsta_transakcije=:id_transakcije    
                                                                  and p.status<>'D'
    order by p.datum, p.vreme
    INTO :ID,
         :DATUM,
         :IDGRADE,
         :IDSMENE,
         :IDLIST,
         :RUNDAY,
         :IDBLEND,
         :BATCH_NO,
         :CASE_NO,
         :IDLABORANTA,
         :SIFRA_RADNIKA,
         :VREME,
         :IZMENA,
         :VRSTA_TRANSAKCIJE,
         :ID_UZORKA,
         :VLAGA,
         :TEMPERATURA,
         :KOLICINA,
         :STATUS,
         :UNOS,
         :VEZA,
         :SUGAR,
         :NICOTIN,
         :GRADE,
         :SMENA,
         :LIST,
         :LABORANT,
         :MESTO_UZORKA,
         :IDTIP,
         :TRANSAKCIJA
  DO
  BEGIN

    select kolicina
    from od_lab_merenja m
    where idprocesa=:id
    and parametar1='OVER1'
    into :kolicina_ov1;

    select kolicina
    from od_lab_merenja m
    where idprocesa=:id
    and parametar1='OVER1/2'
    into :kolicina_ov12;

    select kolicina
    from od_lab_merenja m
    where idprocesa=:id
    and parametar1='OVER1/4'
    into :kolicina_ov14;

    select kolicina
    from od_lab_merenja m
    where idprocesa=:id
    and parametar1='OVER1/8'
    into :kolicina_ov18;

    select kolicina
    from od_lab_merenja m
    where idprocesa=:id
    and parametar1='ONPAN'
    into :kolicina_pan;

        SUSPEND;

  END
END^

SET TERM ; ^

ALTER TABLE OD_PRIMESE ADD AKTIVAN SMALLINT;





CREATE SEQUENCE GEN_OD_LAB_MERENJA_ID;

SET TERM ^ ;

CREATE OR ALTER PROCEDURE SP_GEN_OD_LAB_MERENJA_ID 
returns (
    id integer)
as
begin
  id = gen_id(gen_od_lab_merenja_id, 1);
  suspend;
end^

SET TERM ; ^

CREATE SEQUENCE GEN_OD_PROCESSING_ID;

SET TERM ^ ;

CREATE OR ALTER PROCEDURE SP_GEN_OD_PROCESSING_ID 
returns (
    id integer)
as
begin
  id = gen_id(gen_od_processing_id, 1);
  suspend;
end^

SET TERM ; ^


CREATE SEQUENCE GEN_OD_TRANSAKCIJE_ID;

SET TERM ^ ;

CREATE OR ALTER PROCEDURE SP_GEN_OD_TRANSAKCIJE_ID 
returns (
    id integer)
as
begin
  id = gen_id(gen_od_transakcije_id, 1);
  suspend;
end^

SET TERM ; ^


ALTER TABLE MG_ZG ADD BATCH_NO VARCHAR(10);
ALTER TABLE MG_ZG ADD STATUS INTEGER;
ALTER TABLE MG_ZG ADD IDBLEND INTEGER;
ALTER TABLE MG_ZG ADD BROJ_BATCHA INTEGER;
ALTER TABLE MG_ZG ADD VREME TIMESTAMP;
ALTER TABLE MG_ZG ADD AKTIVAN SMALLINT;

ALTER TABLE MG_STAV ADD BARKOD VARCHAR(10);
ALTER TABLE MG_STAV ADD VREME TIMESTAMP;
ALTER TABLE MG_STAV ADD STATUS SMALLINT;
ALTER TABLE MG_STAV ADD DELETED SMALLINT;
ALTER TABLE OD_BLEND ADD UKUPNO_BALA DOUBLE PRECISION DEFAULT 0 ;

ALTER TABLE MG_STAV ADD TEMP_MASA DOUBLE PRECISION;
ALTER TABLE OD_OBRADA_STATUS ADD NOVO_STANJE SMALLINT;
alter table OD_OBRADA_STATUS add constraint FK_OD_OBRADA_STATUS_1 foreign key (NOVO_STANJE) references OD_OBRADA_STATUS(ID);
ALTER TABLE OD_LIST ADD SAP_BATCH VARCHAR(10);

CREATE TABLE OD_ETIKETE_GP (
    ID INTEGER NOT NULL,
    DEALER VARCHAR(100),
    ORIGIN VARCHAR(10),
    BERBA INTEGER,
    STAND_NETO DOUBLE PRECISION,
    STAND_TARA DOUBLE PRECISION,
    IZMENA TIMESTAMP,
    SIFRA_RADNIKA INTEGER);
alter table OD_ETIKETE_GP
add constraint PK_OD_ETIKETE_GP
primary key (ID);

ALTER TABLE OD_ETIKETE_GP ADD AKTIVAN SMALLINT;


CREATE TABLE OD_OBRADA_GP (
    ID INTEGER NOT NULL,
    BARKOD INTEGER,
    CASE_NO INTEGER,
    GRADE VARCHAR(10),
    MOPI VARCHAR(15),
    SAP_BATCH VARCHAR(10),
    BATCH_NO VARCHAR(10),
    NETO DOUBLE PRECISION,
    TARA DOUBLE PRECISION,
    BRUTO DOUBLE PRECISION,
    DATUM TIMESTAMP,
    CROP INTEGER,
    DEALER VARCHAR(100),
    ORIGIN VARCHAR(50));
alter table OD_OBRADA_GP
add constraint PK_OD_OBRADA_GP
primary key (ID);


CREATE SEQUENCE GEN_OD_OBRADA_GP_ID;
SET TERM ^ ;

CREATE PROCEDURE SP_GEN_OD_OBRADA_GP_ID
RETURNS (ID INTEGER)
AS
BEGIN
  ID = GEN_ID(GEN_OD_OBRADA_GP_ID, 1);
  SUSPEND;
END

^

SET TERM ; ^

ALTER TABLE OD_OBRADA_GP ADD DELETED SMALLINT;
ALTER TABLE OD_OBRADA_GP ADD SIFRA_RADNIKA INTEGER;
ALTER TABLE OD_OBRADA_GP ADD DATE_CHANGE TIMESTAMP;
ALTER TABLE OD_OBRADA_GP ADD RADNIKA_CHANGE INTEGER;

SET TERM ^ ;

CREATE OR ALTER PROCEDURE OD_PREGLED_OTP (
    od_datuma date,
    do_datuma date,
    mg integer,
    doc integer)
returns (
    datumdpo date,
    broj integer,
    balaid integer,
    broj_serije varchar(10),
    kod varchar(20),
    klasa varchar(25),
    grupa integer,
    rack integer,
    idbranja varchar(10),
    iduzgoja varchar(10),
    branje varchar(200),
    uzgoja varchar(200),
    sifra_robe integer,
    izlaz_kol decimal(18,4),
    izlaz_kol_alt decimal(18,4),
    ambalaza_kg numeric(18,4))
as
BEGIN
  FOR
    SELECT 
            m.datumdpo,
            m.broj,
            s.balaid,
            s.broj_serije,
            s.kod,
            c.klasa,
            s.grupa,
            s.rack,
            s.idbranja,
            s.iduzgoja,
            nb.naziv as branje,
            nu.naziv as uzgoja,
            s.sifra_robe,
            s.izlaz_kol,
            s.izlaz_kol_alt,
            (b.ambalaza/1000.0000) as ambalaza_kg
    
        FROM       MG_ZG m INNER JOIN MG_STAV S ON (m.id=s.idzg) and m.datumdpo between :od_datuma and :do_datuma and m.sifra_magacina=:mg and m.sifra_dokumenta=:doc
                          INNER JOIN tsistemklasacena c ON c.klasacenaid=s.klasaid
                          INNER JOIN TBALA b ON b.balaid=s.balaid
                          LEFT JOIN tsistem_nbranja nb ON nb.oznaka=s.idbranja
                          LEFT JOIN tsistem_nuzgoja nu ON nu.oznaka=s.iduzgoja
    
        ORDER BY s.broj_serije
    INTO :DATUMDPO,
         :BROJ,
         :BALAID,
         :BROJ_SERIJE,
         :KOD,
         :KLASA,
         :GRUPA,
         :RACK,
         :IDBRANJA,
         :IDUZGOJA,
         :BRANJE,
         :UZGOJA,
         :SIFRA_ROBE,
         :IZLAZ_KOL,
         :IZLAZ_KOL_ALT,
         :AMBALAZA_KG
  DO
  BEGIN
    SUSPEND;
  END
END
^

SET TERM ; ^

ALTER TABLE MG_STAV ADD TEZINA_OBR DOUBLE PRECISION;
ALTER TABLE MG_STAV ADD BRUTOMASA DOUBLE PRECISION;
ALTER TABLE MG_STAV ADD REKLASIRANO_IZ VARCHAR(10);


CREATE SEQUENCE GEN_TBALA_MG_ID;
SET TERM ^ ;

CREATE PROCEDURE SP_GEN_TBALA_MG_ID
RETURNS (ID INTEGER)
AS
BEGIN
  ID = GEN_ID(GEN_TBALA_MG_ID, 1);
  SUSPEND;
END

^

SET TERM ; ^


